@@ -161,7 +161,7 @@ def NASNet(input_shape=None,
                                       default_size=default_size,
                                       min_size=32,
                                       data_format=backend.image_data_format(),
-                                      require_flatten=False,
+                                      require_flatten=include_top,
                                       weights=weights)
 
     if backend.image_data_format() != 'channels_last':
